@@ -32,6 +32,7 @@ struct MappingOptions {
     bool encode_defaults;
     bool check_enum_values;
     bool generic_extension_methods;
+    bool implicit_maps;
     AccessorStyle accessor_style;
 
     MappingOptions(pTHX_ SV *options_ref);
@@ -58,6 +59,10 @@ public:
 
     const Mapper *find_mapper(const upb::MessageDef *message_def) const;
 
+    static bool is_proto3() {
+        return GOOGLE_PROTOBUF_VERSION >= 3000000;
+    }
+
 private:
     void map_package_or_prefix(pTHX_ const std::string &pb_package, bool is_prefix, const std::string &perl_package_prefix, const MappingOptions &options);
     void map_message_recursive(pTHX_ const google::protobuf::Descriptor *descriptor, const std::string &perl_package, const MappingOptions &options);
